Crate cml_cip25_wasm

Crate cml_cip25_wasm 

Re-exports

pub use utils::CIP25LabelMetadata;

Modules

utils

Structs

CIP25ChunkableString
A String that may or may not be chunked into 64-byte chunks to be able to conform to Cardano TX Metadata limitations. Most users should simply use CIP25ChunkableString::from_string() and CIP25ChunkableString::to_string() and avoid the explicit single/chunk interface:
CIP25FilesDetails
CIP25Metadata
This is the entire metadata schema for CIP-25 It can be parsed by passing in the CBOR bytes of the entire transaction metadata or by passing in an existing Metadata struct. Parsing from CBOR bytes should be marginally faster.
CIP25MetadataDetails
CIP25String64
A String of at most 64 bytes. This is to conform with Cardano metadata restrictions.
CIP25String64List
FilesDetailsList

Enums

CIP25Version
Which version of the CIP25 spec to use. See CIP25 for details. This will change how things are encoded but for the most part contains the same information.
ChunkableStringKind