pub struct CIP25ChunkableString(/* private fields */);Expand description
A String that may or may not be chunked into 64-byte chunks to be able to conform to Cardano TX Metadata limitations. Most users should simply use CIP25ChunkableString::from_string() and CIP25ChunkableString::to_string() and avoid the explicit single/chunk interface:
let chunkableString = CIP25.CIP25ChunkableString.from_string("this can be any length and will automatically be chunked if needed");Implementations
Sourceimpl CIP25ChunkableString
impl CIP25ChunkableString
Sourcepub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes.
- This type does NOT support fine-tuned encoding options so this may or may not be
- canonical CBOR and may or may not preserve round-trip encodings.
Sourcepub fn from_cbor_bytes(
cbor_bytes: &[u8],
) -> Result<CIP25ChunkableString, JsError>
pub fn from_cbor_bytes( cbor_bytes: &[u8], ) -> Result<CIP25ChunkableString, JsError>
- Create this type from CBOR bytes
Sourcepub fn to_cbor_hex(&self) -> String
pub fn to_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes encoded as a hex string (useful for working with CIP30).
- This type does NOT support fine-tuned encoding options so this may or may not be
- canonical CBOR and may or may not preserve round-trip encodings.
Sourcepub fn from_cbor_hex(cbor_bytes: &str) -> Result<CIP25ChunkableString, JsError>
pub fn from_cbor_hex(cbor_bytes: &str) -> Result<CIP25ChunkableString, JsError>
- Create this type from the CBOR bytes encoded as a hex string.
- This is useful for interfacing with CIP30
Sourceimpl CIP25ChunkableString
impl CIP25ChunkableString
pub fn new_single(single: &CIP25String64) -> Self
pub fn new_chunked(chunked: &CIP25String64List) -> Self
pub fn kind(&self) -> ChunkableStringKind
pub fn as_single(&self) -> Option<CIP25String64>
pub fn as_chunked(&self) -> Option<CIP25String64List>