A String that may or may not be chunked into 64-byte chunks to be able
to conform to Cardano TX Metadata limitations.
Most users should simply use CIP25ChunkableString::from_string() and CIP25ChunkableString::to_string()
and avoid the explicit single/chunk interface:
This is the entire metadata schema for CIP-25
It can be parsed by passing in the CBOR bytes of the entire transaction metadata
or by passing in an existing Metadata struct.
Parsing from CBOR bytes should be marginally faster.
Which version of the CIP25 spec to use. See CIP25 for details.
This will change how things are encoded but for the most part contains
the same information.